# Generated by roxygen2: do not edit by hand

S3method(coef,qgarch)
S3method(fitted,qgarch)
S3method(logLik,qgarch)
S3method(plot,qgarch)
S3method(predict,qgarch)
S3method(print,qgarch)
S3method(print,summary.qgarch)
S3method(residuals,qgarch)
S3method(summary,qgarch)
S3method(vcov,qgarch)
export(qgarch_default_starts)
export(qgarch_fit)
export(qgarch_lr_test)
export(qgarch_moments)
