#' Monthly U.S. data
#'
#' Monthly data used in examples and tests for the qgarch package.
#'
#' @format A data frame with monthly observations and 3 variables:
#' \describe{
#'   \item{YearMon}{Month of the observation.}
#'   \item{Mktrf}{Market excess return.}
#'   \item{ER}{Excess return series.}
#' }
#'
#' @source Prepared by the package author.
"us_monthly"