% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{predict.qgarch}
\alias{predict.qgarch}
\title{Forecast from a generalized qgarch(m, n) model}
\usage{
\method{predict}{qgarch}(object, n.ahead = 1L, ...)
}
\arguments{
\item{object}{A fitted \code{qgarch} object.}

\item{n.ahead}{Number of periods ahead to forecast.}

\item{...}{Unused.}
}
\value{
A data frame with forecast horizon, conditional mean,
conditional variance, and conditional standard deviation.
}
\description{
Forecast from a generalized qgarch(m, n) model
}
