% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{qgarch_lr_test}
\alias{qgarch_lr_test}
\title{Likelihood ratio test for nested qgarch models}
\usage{
qgarch_lr_test(restricted, unrestricted, df = NULL)
}
\arguments{
\item{restricted}{A fitted \code{qgarch} object representing the restricted model.}

\item{unrestricted}{A fitted \code{qgarch} object representing the unrestricted model.}

\item{df}{Degrees of freedom for the test. If \code{NULL}, it is computed as the
difference in the number of estimated coefficients.}
}
\value{
A data frame with the likelihood ratio statistic, degrees of freedom,
p-value, and the model names. The returned object has class
\code{c("qgarch_lr_test", "data.frame")}.
}
\description{
Compares two fitted \code{qgarch} models using the likelihood ratio test.
}
