% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{residuals.qgarch}
\alias{residuals.qgarch}
\title{Residuals from a qgarch model}
\usage{
\method{residuals}{qgarch}(object, type = c("raw", "standardized", "eta"), ...)
}
\arguments{
\item{object}{A fitted \code{qgarch} object.}

\item{type}{Type of residuals to return: \code{"raw"}, \code{"standardized"},
or \code{"eta"}.}

\item{...}{Unused.}
}
\value{
A numeric vector of residuals.
}
\description{
Residuals from a qgarch model
}
